import { createTheme } from '@mui/material';
export * from '@mui/material';
import { jsx } from 'react/jsx-runtime';
import MuiButton from '@mui/material/Button';
import { styled } from '@mui/material/styles';
export { StyledEngineProvider, ThemeProvider, useTheme } from '@mui/material/styles';
import React from 'react';
import MuiBox from '@mui/material/Box';
import MuiTypography from '@mui/material/Typography';
import styled$1 from 'styled-components';

var PaletteColors;
(function (PaletteColors) {
    PaletteColors["collageRed"] = "collageRed";
    PaletteColors["collageViolet"] = "collageViolet";
    PaletteColors["collageOrange"] = "collageOrange";
    PaletteColors["collageTeal"] = "collageTeal";
    PaletteColors["collageYellow"] = "collageYellow";
    PaletteColors["uiBlue"] = "uiBlue";
    PaletteColors["uiCoolGray"] = "uiCoolGray";
    PaletteColors["uiWhite"] = "uiWhite";
    PaletteColors["uiGray"] = "uiGray";
    PaletteColors["uiGreen"] = "uiGreen";
    PaletteColors["uiYellow"] = "uiYellow";
    PaletteColors["uiRed"] = "uiRed";
})(PaletteColors || (PaletteColors = {}));

const mapVariantToMui = (variant) => {
    switch (variant) {
        case 'primary':
        case 'secondary':
            return 'contained';
        case 'tertiary':
            return 'outlined';
        case 'text':
        case 'link':
        case 'nav':
            return 'text';
        default:
            return 'contained';
    }
};
const getDefaultColor = (variant) => {
    switch (variant) {
        case 'primary':
        case 'secondary':
            return PaletteColors.collageRed;
        case 'tertiary':
        case 'text':
        case 'nav':
            return PaletteColors.uiGray;
        case 'link':
            return PaletteColors.uiBlue;
        default:
            return PaletteColors.collageRed;
    }
};
const ButtonForwardRef = React.forwardRef(({ customVariant: _customVariant, customColor: _customColor, ...props }, ref) => jsx(MuiButton, { ref: ref, ...props }));
const ButtonRoot = styled(ButtonForwardRef)(({ theme, customVariant, size, customColor }) => {
    const mainColor = customColor ?? getDefaultColor(customVariant);
    return {
        display: 'flex',
        fontSize: 16,
        padding: '8px, 16px',
        textAlign: 'center',
        borderRadius: 4,
        alignItems: 'center',
        boxShadow: 'none',
        textTransform: 'none',
        justifyContent: 'center',
        minHeight: 0,
        whiteSpace: 'nowrap',
        ...(size === 'small' && {
            fontSize: '14px',
            padding: '4px 12px',
        }),
        ...(size === 'medium' && {
            fontSize: '16px',
            padding: '8px 16px',
        }),
        ...(size === 'large' && {
            fontSize: '18px',
            padding: '12px 20px',
        }),
        ...(customVariant === 'primary' && {
            color: theme.palette.uiWhite[500],
            backgroundColor: theme.palette[mainColor][400],
            height: '40px',
            '&:hover': {
                backgroundColor: theme.palette[mainColor][500],
            },
        }),
        ...(customVariant === 'secondary' && {
            color: theme.palette[mainColor][500],
            border: '1px solid',
            borderColor: theme.palette[mainColor][200],
            backgroundColor: theme.palette.uiWhite[500],
            height: '40px',
            '&:hover': {
                backgroundColor: theme.palette[mainColor][50],
                borderColor: theme.palette[mainColor][500],
            },
        }),
        ...(customVariant === 'tertiary' && {
            color: theme.palette[mainColor][800],
            border: '1px solid',
            borderColor: theme.palette[mainColor][200],
            backgroundColor: theme.palette.uiWhite[500],
            height: '40px',
            '&:hover': {
                backgroundColor: theme.palette.uiCoolGray[50],
                borderColor: theme.palette[mainColor][500],
            },
        }),
        ...(customVariant === 'text' && {
            padding: '2px 4px',
            color: theme.palette[mainColor][800],
            '&:hover': {
                background: 'none',
                border: 'none',
                color: theme.palette.collageRed[600],
            },
        }),
        ...(customVariant === 'link' && {
            color: theme.palette[mainColor][600],
            background: 'none',
            padding: '2px 4px',
            borderRadius: 0,
            minWidth: 0,
            '&:hover': {
                ':after': {
                    content: '""',
                    background: theme.palette[mainColor][600],
                    position: 'absolute',
                    bottom: -2,
                    left: '0',
                    height: '1px',
                    width: '100%',
                },
                background: 'none',
            },
            '&:active': {
                background: 'none',
                border: 'none',
                borderRadius: '4px',
                ':after': {
                    content: '""',
                    background: 'none',
                },
            },
        }),
        ...(customVariant === 'nav' && {
            color: theme.palette[mainColor][800],
            background: 'none',
            padding: '2px 4px',
            '&:hover': {
                backgroundColor: theme.palette.uiCoolGray[50],
            },
            '&:active': {
                color: theme.palette.collageRed[500],
                backgroundColor: theme.palette.collageRed[50],
            },
        }),
        '&:disabled': {
            ...(customVariant === 'primary' && {
                backgroundColor: theme.palette.uiCoolGray[100],
                color: theme.palette.uiCoolGray[300],
            }),
            ...(customVariant === 'secondary' && {
                border: '1px solid',
                borderColor: theme.palette.uiCoolGray[100],
                color: theme.palette.uiCoolGray[300],
                backgroundColor: 'transparent',
            }),
            ...(customVariant === 'tertiary' && {
                backgroundColor: 'transparent',
                color: theme.palette.uiCoolGray[300],
                border: 'none',
            }),
        },
    };
});
const Button = React.forwardRef(({ children, variant = 'primary', size = 'medium', color, ...props }, ref) => {
    const muiVariant = mapVariantToMui(variant);
    return (jsx(ButtonRoot, { ref: ref, variant: muiVariant, customVariant: variant, customColor: color, size: size, ...props, children: children }));
});

const Box = (props) => jsx(MuiBox, { ...props });

const fontWeightMapping = {
    regular: 400,
    medium: 500,
    semiBold: 800,
    bold: 900,
};
const TypographyRoot = styled$1(MuiTypography).withConfig({
    shouldForwardProp: (prop) => {
        return prop !== 'weight';
    },
}) `
  font-weight: ${({ weight }) => weight ? fontWeightMapping[weight] : 'inherit'};
`;
const Typography = ({ children, weight = 'regular', component, ...props }) => {
    return (jsx(TypographyRoot, { component: component, weight: weight, ...props, children: children }));
};

const ui = {
    blue: {
        50: '#e7f0f6',
        100: '#b3d1e3',
        200: '#8ebad5',
        300: '#5b9bc2',
        400: '#3b87b6',
        500: '#0a69a4',
        600: '#096095',
        700: '#074b74',
        800: '#063a5a',
        900: '#042c45',
    },
    green: {
        50: '#e8f4ed',
        100: '#b7ddc8',
        200: '#95ccad',
        300: '#64b587',
        400: '#46a770',
        500: '#18914c',
        600: '#168445',
        700: '#116736',
        800: '#0d502a',
        900: '#0a3d20',
    },
    yellow: {
        50: '#fdf5eb',
        100: '#f8e1c0',
        200: '#f5d2a2',
        300: '#f1be77',
        400: '#eeb15d',
        500: '#ea9e34',
        600: '#d5902f',
        700: '#a67025',
        800: '#81571d',
        900: '#624216',
    },
    red: {
        50: '#faebeb',
        100: '#efc0c0',
        200: '#e8a1a1',
        300: '#dd7676',
        400: '#d65c5c',
        500: '#cc3333',
        600: '#ba2e2e',
        700: '#912424',
        800: '#701c1c',
        900: '#561515',
    },
    gray: {
        50: '#efefef',
        100: '#cccccc',
        200: '#b4b4b4',
        300: '#929292',
        400: '#7d7d7d',
        500: '#5c5c5c',
        600: '#545454',
        700: '#414141',
        800: '#333333',
        900: '#272727',
    },
    coolGray: {
        50: '#f2f3f5',
        100: '#d7dbe0',
        200: '#c4cad1',
        300: '#a9b1bb',
        400: '#98a2ae',
        500: '#7e8b9a',
        600: '#737e8c',
        700: '#59636d',
        800: '#454c55',
        900: '#353a41',
    },
    white: {
        500: '#FFFFFF',
    },
};

const collage = {
    red: {
        // collage-group-red
        50: '#f2e8eb',
        100: '#d6b7c2',
        200: '#c295a4',
        300: '#a7647a',
        400: '#954661',
        500: '#7b1839',
        600: '#701634',
        700: '#571128',
        800: '#440d1f',
        900: '#340a18',
    },
    yellow: {
        // multi-cultural-yellow
        50: '#f9f5ed',
        100: '#ebe0c8',
        200: '#e2d1ae',
        300: '#d4bd89',
        400: '#ccb072',
        500: '#bf9c4f',
        600: '#ae8e48',
        700: '#886f38',
        800: '#69562b',
        900: '#504221',
    },
    orange: {
        // generations-orange
        50: '#faf0ed',
        100: '#efd2c8',
        200: '#e8bcae',
        300: '#dd9d89',
        400: '#d68a72',
        500: '#cc6d4f',
        600: '#ba6348',
        700: '#914d38',
        800: '#703c2b',
        900: '#562e21',
    },
    violet: {
        // lgbtq-gender-violet
        50: '#faebeb',
        100: '#efc0c0',
        200: '#e8a1a1',
        300: '#dd7676',
        400: '#d65c5c',
        500: '#cc3333',
        600: '#ba2e2e',
        700: '#912424',
        800: '#701c1c',
        900: '#561515',
    },
    teal: {
        // parents-kids-teal
        50: '#e9f3f3',
        100: '#bbdada',
        200: '#9ac9c8',
        300: '#6cb0af',
        400: '#50a19f',
        500: '#248987',
        600: '#217d7b',
        700: '#1a6160',
        800: '#144b4a',
        900: '#0f3a39',
    },
};

const pxToRem = createTheme().typography.pxToRem;
const capitalize = (text) => {
    return text.charAt(0).toUpperCase() + text.slice(1);
};
const generatePalette = (swatch, name) => {
    const palette = {};
    for (const color in swatch) {
        const colorKey = `${name}${capitalize(color)}`;
        palette[colorKey] = {
            ...swatch[color],
        };
    }
    // ex: 'uiYellow': { '50': '#fdf5eb', '100': '#f8e1c0' }
    return palette;
};
const palette = {
    ...generatePalette(ui, 'ui'),
    ...generatePalette(collage, 'collage'),
};
const themeOptions = {
    palette,
    typography: {
        fontFamily: "'Roboto', sans-serif",
        fontSize: 16,
        h4: undefined,
        h5: undefined,
        h6: undefined,
        subtitle1: undefined,
        subtitle2: undefined,
        body1: undefined,
        body2: undefined,
        button: undefined,
        overline: undefined,
        h1: {
            fontSize: pxToRem(28),
            lineHeight: pxToRem(38),
        },
        h2: {
            fontSize: pxToRem(24),
            lineHeight: pxToRem(33),
        },
        h3: {
            fontSize: pxToRem(20),
            lineHeight: pxToRem(27),
        },
        b1: {
            fontSize: pxToRem(16),
            lineHeight: pxToRem(22),
        },
        b2: {
            fontSize: pxToRem(14),
            lineHeight: pxToRem(19),
        },
        b3: {
            fontSize: pxToRem(12),
            lineHeight: pxToRem(16),
        },
        caption: {
            fontSize: pxToRem(10),
            lineHeight: pxToRem(20),
        },
    },
    components: {
        MuiTypography: {
            styleOverrides: {
                root: {
                    fontWeight: 'unset',
                },
            },
            defaultProps: {
                fontFamily: "'Roboto', sans-serif",
                // by default, new variants will render as span
                variantMapping: {
                    b1: 'p',
                    b2: 'p',
                    b3: 'p',
                },
            },
        },
    },
};
const theme = createTheme(themeOptions);

export { Box, Button, PaletteColors, Typography, collage, palette, theme, ui };
//# sourceMappingURL=index.js.map
